require(saemix)
require(reshape2)
dat<-read.csv("knutson_et_al_2016.csv")
dat<-melt(t(dat))
# create data-set
dat$Var1<-rep(seq(0,45,by=3),times=6)
colnames(dat)<-c("Day","Id","Vol")
dat$Rad<-(3*dat$Vol/(4*pi))^(1/3)

linear_growth<-function(psi,id,xidep) { 
  time<-xidep[,1]  
  r0<-psi[id,1]
  g<-psi[id,2]
  ypred<-r0+g*time
  return(ypred)
}
saemix.data<-saemixData(name.data=dat,header=TRUE,sep=" ",na=NA,
                        name.group=c("Id"),name.predictors=c("Day"),
                        name.response=c("Rad"),
                        units=list(x="day",y="mm", covariates=c("-")), name.X="Day")

saemix.model<-saemixModel(model=linear_growth,
                          description="Linear growth of radius over time", 
                          psi0=matrix(c(1,1),ncol=2, byrow=TRUE,
                                      dimnames=list(NULL, c("r0","g"))),
                          transform.par=c(0,0),
                          fixed.estim=c(1,1),
                          covariance.model=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                          omega.init=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                          error.model="constant") # here is where we can play

saemix.fit1<-saemix(saemix.model,saemix.data,list(seed=123456,nb.chains=10,
                                                  nbiter.saemix=c(1000,500),save=FALSE,
                                                  save.graphs=FALSE))
print(saemix.fit1)
plot(saemix.fit1)
saemix.fit1@results@predictions<-data.frame()
advanced.gof(saemix.fit1)

saemix.model<-saemixModel(model=linear_growth,
                          description="Linear growth of radius over time", 
                          psi0=matrix(c(1,1),ncol=2, byrow=TRUE,
                                      dimnames=list(NULL, c("r0","g"))),
                          transform.par=c(0,0),
                          fixed.estim=c(1,1),
                          covariance.model=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                          omega.init=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                          error.model="proportional") # here is where we can play
saemix.fit2<-saemix(saemix.model,saemix.data,list(seed=123456,nb.chains=3,
                                                  nbiter.saemix=c(1000,500)))
print(saemix.fit2)
0.0015/0.11# 1.5%
print(saemix.fit1)
# so we actually got a better fit to the data using proportional error model
# compare the AIC between the two models
plot(saemix.fit2)
saemix.fit2@results@predictions<-data.frame()
advanced.gof(saemix.fit2)


