
require(saemix)
require(readxl)
require(dplyr)
require(ggplot2)
require(nlme)

#import raw xenograft data
raw_data<- read_xlsx("nm.3954-S2.xlsx", sheet = "PCT raw data", col_names = T)
#convert to dataframe
raw_data<- as.data.frame(raw_data)

#filter for first 14 days of study (typical length of xenograft study)
xeno14<- raw_data %>%
  filter(`Days Post T0` <= 14)
#select the controls
ctl<-xeno14[xeno14$Treatment=="untreated",]
colnames(ctl)<-c("Id","Type","Trt","Vol","Bw","Day","PerVolDiff",
                 "PerBwDiff")
ctl$Rad<-((3/(4*pi))*ctl$Vol)^(1/3)

# create an index for mice
Nid<-array(NA,dim=c(length(ctl$Id),1))
Nid[1]<-1
for(ii in 2:length(ctl$Id)){
  if(ctl$Id[ii]!=ctl$Id[ii-1]){
    Nid[ii]<-Nid[ii-1]+1
  }else{
    Nid[ii]<-Nid[ii-1]
  }
}
ctl<-cbind(ctl,Nid)

#now we fit models to data using SAEMIX
ctl<-ctl[is.na(ctl$Rad)==F,]
ctl<-ctl[,c("Nid","Day","Rad")]
saemix.data<-saemixData(name.data=ctl,header=TRUE,sep=" ",na=NA,
                        name.group=c("Nid"),name.predictors=c("Day"),
                        name.response=c("Rad"),
                        units=list(x="day",y="mm"), name.X="Day")

linear_growth<-function(psi,id,xidep) { 
  time<-xidep[,1]  
  r0<-psi[id,1]
  g<-psi[id,2]
  ypred<-r0+g*time
  return(ypred)
}

saemix.model<-saemixModel(model=linear_growth,
                          description="Linear growth of radius over time", 
                          psi0=matrix(c(1,1),ncol=2, byrow=TRUE,
                                      dimnames=list(NULL, c("r0","g"))),
                          transform.par=c(0,0),
                          fixed.estim=c(1,1),
                          covariance.model=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                          omega.init=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                          error.model="constant") # here is where we can play

saemix.fit1<-saemix(saemix.model,saemix.data,list(seed=123456,nb.chains=3,
                                                 nbiter.saemix=c(1000,500)))
print(saemix.fit1)
plot(saemix.fit1)
saemix.fit1@results@predictions<-data.frame()
advanced.gof(saemix.fit1)

saemix.model<-saemixModel(model=linear_growth,
                          description="Linear growth of radius over time", 
                          psi0=matrix(c(1,1),ncol=2, byrow=TRUE,
                                      dimnames=list(NULL, c("r0","g"))),
                          transform.par=c(0,0),
                          fixed.estim=c(1,1),
                          covariance.model=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                          omega.init=matrix(c(1,0,0,1),ncol=2,byrow=TRUE),
                          error.model="proportional") # here is where we can play
saemix.fit2<-saemix(saemix.model,saemix.data,list(seed=123456,nb.chains=3,
                                                  nbiter.saemix=c(1000,500)))
print(saemix.fit2)
print(saemix.fit1)
# so we actually got a better fit to the data using proportional error model
# compare the AIC between the two models
plot(saemix.fit2)
saemix.fit2@results@predictions<-data.frame()
advanced.gof(saemix.fit2)
# I think this means we should 

